Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/fastoai/__init__.py | 18 | 4 | 0 | 78%
src/fastoai/__main__.py | 2 | 2 | 0 | 0%
src/fastoai/cli.py | 12 | 12 | 0 | 0%
src/fastoai/dependencies.py | 32 | 12 | 0 | 62%
src/fastoai/models/__init__.py | 21 | 0 | 0 | 100%
src/fastoai/models/_codegen.py | 157 | 1 | 0 | 99%
src/fastoai/models/_metadata.py | 32 | 4 | 0 | 88%
src/fastoai/models/_types.py | 81 | 20 | 0 | 75%
src/fastoai/models/_utils.py | 11 | 0 | 0 | 100%
src/fastoai/models/generated/assistant.py | 38 | 3 | 0 | 92%
src/fastoai/models/generated/file_object.py | 23 | 4 | 0 | 83%
src/fastoai/models/generated/message.py | 39 | 6 | 0 | 85%
src/fastoai/models/generated/run.py | 58 | 8 | 0 | 86%
src/fastoai/models/generated/run_step.py | 41 | 6 | 0 | 85%
src/fastoai/models/generated/thread.py | 28 | 7 | 0 | 75%
src/fastoai/models/user.py | 52 | 2 | 0 | 96%
src/fastoai/pagination.py | 19 | 2 | 0 | 89%
src/fastoai/routers/__init__.py | 26 | 9 | 0 | 65%
src/fastoai/routers/_client.py | 11 | 1 | 0 | 91%
src/fastoai/routers/_types.py | 5 | 0 | 0 | 100%
src/fastoai/routers/_utils.py | 7 | 1 | 0 | 86%
src/fastoai/routers/beta/__init__.py | 14 | 0 | 0 | 100%
src/fastoai/routers/beta/assistants.py | 56 | 25 | 0 | 55%
src/fastoai/routers/beta/messages.py | 24 | 11 | 0 | 54%
src/fastoai/routers/beta/run_steps.py | 2 | 0 | 0 | 100%
src/fastoai/routers/beta/runs.py | 80 | 60 | 0 | 25%
src/fastoai/routers/beta/threads.py | 21 | 9 | 0 | 57%
src/fastoai/routers/files.py | 53 | 30 | 0 | 43%
src/fastoai/routers/models.py | 15 | 3 | 0 | 80%
src/fastoai/settings.py | 19 | 0 | 0 | 100%
Total | 997 | 242 | 0 | 76%

No items found using the specified filter.